Index: src/interpreter/bytecode-array-builder.h |
diff --git a/src/interpreter/bytecode-array-builder.h b/src/interpreter/bytecode-array-builder.h |
index b0ca11709cafbd27d96e56a140c5fa6441b8d4b9..da0262a20b8cbb20ef1e60e5a2f40b4fbcadbf0e 100644 |
--- a/src/interpreter/bytecode-array-builder.h |
+++ b/src/interpreter/bytecode-array-builder.h |
@@ -139,10 +139,11 @@ class BytecodeArrayBuilder final : public ZoneObject { |
// in the accumulator. |
BytecodeArrayBuilder& CreateBlockContext(Handle<ScopeInfo> scope_info); |
// Create a new context for a catch block with |exception| and |name| and the |
// closure in the accumulator. |
BytecodeArrayBuilder& CreateCatchContext(Register exception, |
- Handle<String> name); |
+ Handle<String> name, |
+ Handle<ScopeInfo> scope_info); |
// Create a new context with size |slots|. |
BytecodeArrayBuilder& CreateFunctionContext(int slots); |
@@ -139,10 +139,11 @@ class BytecodeArrayBuilder final : public ZoneObject { |
// in the accumulator. |
BytecodeArrayBuilder& CreateBlockContext(Handle<ScopeInfo> scope_info); |
- // Create a new context for a catch block with |exception| and |name| and the |
- // closure in the accumulator. |
+ // Create a new context for a catch block with |exception|, |name|, |
+ // |scope_info|, and the closure in the accumulator. |
BytecodeArrayBuilder& CreateCatchContext(Register exception, |